#
# bash completion support for ubuntuzilla
# 
# Part of the Ubuntuzilla project
# http://ubuntuzilla.sourceforge.net/
# 
# Initial version contributed by:
# Mathieu Turcotte <turcotte.mat@gmail.com>
# 
# Further modifications by:
# Daniel Folkinshteyn <nanotube@users.sourceforge.net>
# 
# Copyright (C) 2009 Mathieu Turcotte <turcotte.mat@gmail.com> and
# Daniel Folkinshteyn <nanotube@users.sourceforge.net>
# Distributed under the GNU General Public License, version 3.0, 
# or, at your option, any later version.
# 
# The completion routines provide support for completing:
#     *) command-line arguments
#     *) actions supported by --action
#     *) packages supported by --package
# 
# This file will automatically be installed into /etc/bash_completion.d/ by the
# ubuntuzilla .deb package.
# 

have ubuntuzilla.py &&
_ubuntuzilla()
{
    local cur prev dirNames
    COMPREPLY=()
    dirNames=''
    cur="${COMP_WORDS[COMP_CWORD]}"
    prev="${COMP_WORDS[COMP_CWORD-1]}"
    
    if [[ "${cur}" == -* ]] ; then
        COMPREPLY=( $(compgen -W "-a -d -h -t -p -g -u -l -b -r -m -k \
                      --version --help --test --package --action --skipgpg \
                      --unattended --localization --skipbackup --targetdir \
                      --mirror --keyservers" -- ${cur}) )
    fi
    
    case ${prev} in
        -p|--package|--package=)
            COMPREPLY=( $(compgen -W "firefox thunderbird \
                      seamonkey" -- ${cur} ) )
            ;;
        -a|--action|--action=)
            COMPREPLY=( $(compgen -W "install remove \
                      installupdater removeupdater \
                      checkforupdatetext checkforupdategui \
                      updateubuntuzilla" -- ${cur} ) )
            ;;
        -t|--targetdir|--targetdir=)
            dirNames=$( compgen -d -- "${cur}" )
            COMPREPLY=( $( compgen -W "$dirNames" -- ${cur} ) )
            ;;
    esac
    
    return 0
}

[ "$have" ] && 
complete -F _ubuntuzilla -o filenames ubuntuzilla.py
